@@ -126,6 +126,9 @@ class RSyncManager(qt.QObject):
         if not len(sources) == len(targets):
             raise ValueError('you should provide one target per source')
 
+        if delete is None:
+            delete = [False] * len(sources)
+
         if callback is not None:
             callback_obj = _MergeCallback(n_call=len(sources),
                                           callback=callback,
@@ -259,8 +262,7 @@ class RSyncManager(qt.QObject):
             self.rsyncQueues[(dir, None)].rsyncThread.wait()
 
     def sync_folder_raw(self, source, target, options, block=False,
-                        callback=None, callback_parameters=None, parallel=False,
-                        timeout=5):
+                        callback=None, callback_parameters=None, parallel=False):
         """sync a folder launching directly the options given. Used for
         benchmarking.
 
@@ -288,7 +290,7 @@ class RSyncManager(qt.QObject):
         if block is True or self._force_sync is True:
             # wait until al thread are ended
             while (source, target) in self.rsyncQueues:
-                self.rsyncQueues[(source, target)].wait(timeout)
+                self.rsyncQueues[(source, target)].wait()
 
         _queue = self._get_queue((source, target), self._managed_finished_sync)
         _queue.add(source=source, target=target, options=options,
@@ -296,7 +298,7 @@ class RSyncManager(qt.QObject):
                    callback_parameters=callback_parameters)
 
         if block is True or self._force_sync is True:
-            self.rsyncQueues[(source, target)].rsyncThread.wait(timeout)
+            self.rsyncQueues[(source, target)].rsyncThread.wait()
 
     def _managed_finished_sync(self, source, target):
         if self.rsyncQueues[(source, target)].empty() is True:
@@ -460,10 +462,6 @@ class _RSyncQueue(SetQueue, qt.QObject):
         self.sigQueueFinished.emit(source, target)
         self.exec_next()
 
-    def wait(self, timeout=5):
-        for thread in self.threads:
-            thread.wait(timeout)
-
 
 # TODO: remove qt dependency
 class _RSyncThread(qt.QThread):
